pub struct KeyState(pub u32);Expand description
physical key state
Describes the physical state of a key that produced the key event.
Since version 10, the key can be in a “repeated” pseudo-state which means the same as “pressed”, but is used to signal repetition in the key event.
The key may only enter the repeated state after entering the pressed state and before entering the released state. This event may be generated multiple times while the key is down.
Tuple Fields
0: u32Implementations