KeyState

Struct KeyState 

#[non_exhaustive]
pub struct KeyState(pub u32);
physical key state

Describes the physical state of a key that produced the key event.

Since version 10, the key can be in a “repeated” pseudo-state which means the same as “pressed”, but is used to signal repetition in the key event.

The key may only enter the repeated state after entering the pressed state and before entering the released state. This event may be generated multiple times while the key is down.

Tuple Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
0: u32

Implementations

Source

impl KeyState

pub const Released: Self

key is not pressed

pub const Pressed: Self

key is pressed

pub const Repeated: Self

key was repeated